# TargetPath

TargetPath defines the target path of the DataLoad
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**path** | **str** | Path defines path to be load | [default to '']
**replicas** | **int** | Replicas defines how many replicas will be loaded | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


